/*
 * irreco - Ir Remote Control
 * Copyright (C) 2007  Arto Karppinen (arto.karppinen@iki.fi)
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */


/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Typedef                                                                    */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/*
 * Make sure that typedefs are available before we include anything elese.
 *
 * This makes sure that whatever other structures that depend on structures 
 * defined in this file will compile OK recardles of header inclusion order.
 */
#ifndef __IRRECO_WEBDB_CLIENT_TYPEDEF__
#define __IRRECO_WEBDB_CLIENT_TYPEDEF__
typedef struct _IrrecoWebdbClient IrrecoWebdbClient;
#endif /* __IRRECO_WEBDB_CLIENT_TYPEDEF__ */
 


/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Include                                                                    */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
#ifndef __IRRECO_WEBDB_CLIENT__
#define __IRRECO_WEBDB_CLIENT__
#include "irreco_webdb.h"

#include <stdlib.h>
#include <stdio.h>
#include "irreco_webdb_conf.h"
#include <libsoup/soup.h>
#include <libsoup/soup-xmlrpc-message.h>


/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Datatypes                                                                  */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/

struct _IrrecoWebdbClient
{
	GString			*error_msg;
};



/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Macro                                                                      */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/



/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
/* Prototypes                                                                 */
/*=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-*/
IrrecoWebdbClient *irreco_webdb_client_new();
void irreco_webdb_client_free(IrrecoWebdbClient *self);
void irreco_webdb_client_get_error_msg(IrrecoWebdbClient *self, GString *msg);
gboolean irreco_webdb_client_add_user(IrrecoWebdbClient *self, 
				      const gchar *name, 
				      const gchar *email,
				      const gchar *passwd);
gboolean irreco_webdb_client_add_uber(IrrecoWebdbClient *self, 
				      const gchar *name, 
				      const gchar *email,
				      const gchar *passwd);
gboolean irreco_webdb_client_upload_configuration(IrrecoWebdbClient *self,
						  const gchar *backend,
						  const gchar *category,
						  const gchar *file_hash,
						  const gchar *file_name,
						  const gchar *manufacturer,
						  const gchar *model,
						  const gchar *password,
						  const gchar *user,
						  const gchar *data);

gboolean irreco_webdb_client_sum(IrrecoWebdbClient *self, 
				 gint num_a, 
				 gint num_b, 
				 gint *sum);
gboolean irreco_webdb_client_get_categories(IrrecoWebdbClient *self, 
					    IrrecoStringTable **category_list);

gboolean irreco_webdb_client_get_all_categories(IrrecoWebdbClient *self, 
					    IrrecoStringTable **category_list);

gboolean irreco_webdb_client_get_manufacturers(IrrecoWebdbClient *self,
					const gchar *category, 
					IrrecoStringTable **manufacturer_list);

gboolean irreco_webdb_client_get_all_manufacturers(IrrecoWebdbClient *self, 
			    IrrecoStringTable **manufacturer_list);

gboolean irreco_webdb_client_get_models(IrrecoWebdbClient *self,
					const gchar *category,
					const gchar *manufacturer, 
     					IrrecoStringTable **model_list);
     					
gboolean irreco_webdb_client_get_configs(IrrecoWebdbClient *self,
					 const gchar *category,
					 const gchar *manufacturer,
					 const gchar *model, 
					 IrrecoStringTable **config_list);

gboolean irreco_webdb_client_get_configuration(IrrecoWebdbClient *self,
					       gint id,
					       IrrecoWebdbConf **configuration);
					       
gboolean irreco_webdb_client_get_file(IrrecoWebdbClient *self,
				      const gchar *file_hash,
				      const gchar *file_name,
				      GString **file_data);
     					
gboolean irreco_webdb_client_get_user_exists(IrrecoWebdbClient *self, 
				const gchar *name, gboolean *user_exists);

#endif /* __IRRECO_WEBDB_CLIENT__ */


